<?php

/*
 * @template  Bootstrap
 * @revised   December 20, 2011
 * @author    digitalnature, http://digitalnature.eu
 * @license   GPL, http://www.opensource.org/licenses/gpl-license
 */

// Reply form template part.
// For use with the bbPress plugin only.

?>

<?php if(bbp_current_user_can_access_create_reply_form()): ?>



<div class="well clear-block">

  <div class="avatar alignleft">
    <?php bbp_is_reply_edit() ? bbp_reply_author_avatar(bbp_get_reply_id(), 48) : bbp_current_user_avatar(48); ?>
  </div>

  <div class="block-wrap">

    <?php if(current_user_can('unfiltered_html')): ?>
    <div class="bbp-template-notice">
      <p><?php atom()->te('Your account has the ability to post unrestricted HTML content.'); ?></p>
    </div>
    <?php endif; ?>

  </div>
</div>

<div class="bbp-reply-form" id="new-reply-<?php bbp_topic_id(); ?>">

  <form id="new-post" name="new-post" method="post" action="">

    <?php do_action('bbp_theme_before_reply_form'); ?>

    <?php do_action('bbp_theme_before_reply_form_notices'); ?>

    <?php if(!bbp_is_topic_open() && !bbp_is_reply_edit()): ?>
    <div class="bbp-template-notice">
      <p><?php atom()->te('This topic is marked as closed to new replies, however your posting capabilities still allow you to do so.'); ?></p>
    </div>
    <?php endif; ?>

    <?php do_action('bbp_template_notices'); ?>

    <fieldset>

      <?php bbp_get_template_part('templates/form', 'anonymous'); ?>

      <?php do_action('bbp_theme_before_reply_form_content'); ?>
      <div class="clear-block <?php if($error = $GLOBALS['bbp']->errors->get_error_message('bbp_reply_content')) echo 'error'; ?>">
        <label for="bbp_reply_content"><?php atom()->te('Reply:'); ?></label>
        <div class="input">
          <textarea id="bbp_reply_content" tabindex="<?php bbp_tab_index(); ?>" name="bbp_reply_content" cols="51" rows="6"><?php bbp_form_reply_content(); ?></textarea>
          <?php if($error): ?>
          <span class="help-inline"><?php echo $error; ?></span>
          <?php endif; ?>
          <?php if(!current_user_can('unfiltered_html')): ?>
          <span class="help-block">
            <?php atom()->te('You may use these %s tags and attributes:', '<abbr title="HyperText Markup Language">HTML</abbr>'); ?>
            <code><?php bbp_allowed_tags(); ?></code>
          </span>
          <?php endif; ?>
        </div>
      </div>
      <?php do_action('bbp_theme_after_reply_form_content'); ?>

      <?php do_action('bbp_theme_before_reply_form_tags'); ?>
      <div class="clear-block">
        <label for="bbp_topic_tags"><?php atom()->te('Tags:'); ?></label>
        <div class="input">
          <input id="bbp_topic_tags" type="text" value="<?php bbp_form_topic_tags(); ?>" tabindex="<?php bbp_tab_index(); ?>" size="40" name="bbp_topic_tags" />
        </div>
      </div>
      <?php do_action('bbp_theme_after_reply_form_tags'); ?>

      <?php if(bbp_is_subscriptions_active() && !bbp_is_anonymous() && (!bbp_is_reply_edit() || (bbp_is_reply_edit() && !bbp_is_reply_anonymous()))): ?>
      <?php do_action('bbp_theme_before_reply_form_subscription'); ?>


      <div class="clear-block">
        <div class="input">
          <ul class="inputs-list">
            <li>
              <label for="bbp_topic_subscription">
                <input name="bbp_topic_subscription" id="bbp_topic_subscription" type="checkbox" value="bbp_subscribe" <?php bbp_form_topic_subscribed(); ?> tabindex="<?php bbp_tab_index(); ?>" />
                <span><?php (bbp_is_reply_edit() && $post->post_author != bbp_get_current_user_id()) ? atom()->te('Notify the author of follow-up replies via email') : atom()->te('Notify me of follow-up replies via email'); ?></span>
              </label>
            </li>
          </ul>
        </div>
      </div>
      <?php do_action('bbp_theme_after_reply_form_subscription'); ?>
      <?php endif; ?>


      <?php if(bbp_allow_revisions() && bbp_is_reply_edit()): ?>
      <?php do_action('bbp_theme_before_reply_form_revisions'); ?>


      <div class="clear-block">
        <label for="bbp_log_reply_edit"><?php atom()->te('Keep a log of this edit'); ?></label>
        <div class="input">
          <div class="input-prepend">
            <label class="add-on active">
              <input name="bbp_log_reply_edit" id="bbp_log_reply_edit" type="checkbox" value="1" <?php bbp_form_reply_log_edit(); ?> tabindex="<?php bbp_tab_index(); ?>" />
            </label>
            <input type="text" value="<?php bbp_form_reply_edit_reason(); ?>" tabindex="<?php bbp_tab_index(); ?>" size="40" name="bbp_reply_edit_reason" id="bbp_reply_edit_reason" />

            <span class="help-block"><?php atom()->te('Optionally, you can provide a reason for editing.'); ?></span>
          </div>
        </div>
      </div>
      <?php do_action('bbp_theme_after_reply_form_revisions'); ?>

      <?php else: ?>
        <?php bbp_topic_admin_links(); ?>

      <?php endif; ?>

      <?php do_action('bbp_theme_before_reply_form_submit_wrapper'); ?>
      <div class="actions">
        <?php do_action('bbp_theme_before_reply_form_submit_button'); ?>
        <input type="submit" tabindex="<?php bbp_tab_index(); ?>" class="button ok" name="bbp_reply_submit" value="<?php atom()->te('Submit'); ?>" />
        <?php do_action('bbp_theme_after_reply_form_submit_button'); ?>
      </div>
      <?php do_action('bbp_theme_after_reply_form_submit_wrapper'); ?>

      <?php bbp_reply_form_fields(); ?>

    </fieldset>

    <?php do_action('bbp_theme_after_reply_form'); ?>
  </form>

</div>


<?php elseif(bbp_is_topic_closed()): ?>

  <div id="no-reply-<?php bbp_topic_id(); ?>" class="bbp-no-reply">
    <div class="bbp-template-notice">
      <p><?php atom()->te('The topic &#8216;%s&#8217; is closed to new replies.', bbp_get_topic_title()); ?></p>
    </div>
  </div>

<?php elseif(bbp_is_forum_closed(bbp_get_topic_forum_id())): ?>

  <div id="no-reply-<?php bbp_topic_id(); ?>" class="bbp-no-reply">
    <div class="bbp-template-notice">
      <p><?php atom()->te('The forum &#8216;%s&#8217; is closed to new topics and replies.', bbp_get_forum_title(bbp_get_topic_forum_id())); ?></p>
    </div>
  </div>

<?php else: ?>

  <div id="no-reply-<?php bbp_topic_id(); ?>" class="bbp-no-reply">
    <div class="bbp-template-notice">
      <p><?php is_user_logged_in() ? atom()->te('You cannot reply to this topic.') : atom()->te('You must be logged in to reply to this topic.'); ?></p>
    </div>
  </div>

<?php endif; ?>
