<?php

/*
 * @template  Bootstrap
 * @revised   December 20, 2011
 * @author    digitalnature, http://digitalnature.eu
 * @license   GPL, http://www.opensource.org/licenses/gpl-license
 */

// Topic form template part.
// For use with the bbPress plugin only.

?>

<?php if(!bbp_is_single_forum()) bbp_breadcrumb(); ?>

<?php if(bbp_is_topic_edit()): ?>
  <?php bbp_topic_tag_list(bbp_get_topic_id()); ?>
  <?php bbp_single_topic_description(array('topic_id' => bbp_get_topic_id())); ?>
<?php endif; ?>

<?php if(bbp_current_user_can_access_create_topic_form()): ?>


<div class="well clear-block">

  <div class="avatar alignleft">
    <?php bbp_is_topic_edit() ? bbp_topic_author_avatar(bbp_get_topic_id(), 48) : bbp_current_user_avatar(48); ?>
  </div>

  <div class="block-wrap">


    <?php if(current_user_can('unfiltered_html')): ?>
    <div class="bbp-template-notice">
      <p><?php atom()->te('Your account has the ability to post unrestricted HTML content.'); ?></p>
    </div>
    <?php endif; ?>

    <?php do_action('bbp_template_notices'); ?>

  </div>

</div>

<div class="bbp-topic-form" id="new-topic-<?php bbp_topic_id(); ?>">

  <form id="new-post" name="new-post" method="post" action="">

    <?php do_action('bbp_theme_before_topic_form'); ?>

    <?php do_action('bbp_theme_before_topic_form_notices'); ?>

    <?php if(!bbp_is_topic_edit() && bbp_is_forum_closed()): ?>
    <div class="bbp-template-notice">
      <p><?php atom()->te('This forum is marked as closed to new topics, however your posting capabilities still allow you to do so.'); ?></p>
    </div>
    <?php endif; ?>


    <fieldset>
      <?php bbp_get_template_part('templates/form', 'anonymous'); ?>

      <?php do_action('bbp_theme_before_topic_form_title'); ?>

      <div class="clear-block <?php if($error = $GLOBALS['bbp']->errors->get_error_message('bbp_topic_title')) echo 'error'; ?>">
        <label for="bbp_topic_title"><?php atom()->te('Topic Title:'); ?></label>
        <div class="input">
          <input type="text" id="bbp_topic_title" value="<?php bbp_form_topic_title(); ?>" tabindex="<?php bbp_tab_index(); ?>" size="40" name="bbp_topic_title" maxlength="<?php bbp_title_max_length(); ?>" />
          <?php if($error): ?>
          <span class="help-inline"><?php echo $error; ?></span>
          <?php endif; ?>
          <span class="help-block">
            <?php atom()->te('Maximum %d characters', bbp_get_title_max_length()); ?>
          </span>
        </div>
      </div>

      <?php do_action('bbp_theme_after_topic_form_title'); ?>
      <?php do_action('bbp_theme_before_topic_form_content'); ?>

      <div class="clear-block <?php if($error = $GLOBALS['bbp']->errors->get_error_message('bbp_topic_content')) echo 'error'; ?>">
        <label for="bbp_topic_content"><?php atom()->te('Topic Description:'); ?></label>
        <div class="input">

          <textarea id="bbp_topic_content" tabindex="<?php bbp_tab_index(); ?>" name="bbp_topic_content" cols="51" rows="6"><?php bbp_form_topic_content(); ?></textarea>
          <?php if($error): ?>
          <span class="help-inline"><?php echo $error; ?></span>
          <?php endif; ?>
          <?php if(!current_user_can('unfiltered_html')): ?>
          <span class="help-block">
            <?php atom()->te('You may use these %s tags and attributes:', '<abbr title="HyperText Markup Language">HTML</abbr>'); ?>
            <code><?php bbp_allowed_tags(); ?></code>
          </span>
          <?php endif; ?>

        </div>

      </div>
      <?php do_action('bbp_theme_after_topic_form_content'); ?>

      <?php do_action('bbp_theme_before_topic_form_tags'); ?>

      <div class="clear-block">
        <label for="bbp_topic_tags"><?php atom()->te('Topic Tags:'); ?></label>
        <div class="input">
          <input type="text" value="<?php bbp_form_topic_tags(); ?>" tabindex="<?php bbp_tab_index(); ?>" size="40" name="bbp_topic_tags" id="bbp_topic_tags" />
        </div>
      </div>

      <?php do_action('bbp_theme_after_topic_form_tags'); ?>

      <?php if(!bbp_is_single_forum()): ?>
      <?php do_action('bbp_theme_before_topic_form_forum'); ?>
        <div class="clear-block">
          <label for="bbp_forum_id"><?php atom()->te('Forum:'); ?></label>
          <div class="input">
            <?php bbp_dropdown(array('selected' => bbp_get_form_topic_forum())); ?>
           </div>
        </div>
      <?php do_action('bbp_theme_after_topic_form_forum'); ?>
      <?php endif; ?>


      <?php if(current_user_can('moderate')): ?>
      <?php do_action('bbp_theme_before_topic_form_type'); ?>
        <div class="clear-block">
          <label for="bbp_stick_topic"><?php atom()->te('Topic Type:'); ?></label>
          <div class="input">
            <?php bbp_topic_type_select(); ?>
           </div>
        </div>
      <?php do_action('bbp_theme_after_topic_form_type'); ?>
      <?php endif; ?>


      <?php if(bbp_is_subscriptions_active() && !bbp_is_anonymous() && (!bbp_is_topic_edit() || (bbp_is_topic_edit() && !bbp_is_topic_anonymous()))): ?>
      <?php do_action('bbp_theme_before_topic_form_subscriptions'); ?>
      <div class="clear-block">
        <div class="input">
          <ul class="inputs-list">
            <li>
              <label for="bbp_topic_subscription">
                <input name="bbp_topic_subscription" id="bbp_topic_subscription" type="checkbox" value="bbp_subscribe" <?php bbp_form_topic_subscribed(); ?> tabindex="<?php bbp_tab_index(); ?>" />
                <span><?php (bbp_is_topic_edit() && ($post->post_author != bbp_get_current_user_id())) ? atom()->te('Notify the author of follow-up replies via email') : atom()->te('Notify me of follow-up replies via email'); ?></span>
              </label>
            </li>
          </ul>
        </div>
      </div>
      <?php do_action('bbp_theme_after_topic_form_subscriptions'); ?>
      <?php endif; ?>


      <?php if(bbp_allow_revisions() && bbp_is_topic_edit()): ?>
      <?php do_action('bbp_theme_before_topic_form_revisions'); ?>
      <div class="clear-block">
        <label for="bbp_log_topic_edit"><?php atom()->te('Keep a log of this edit'); ?></label>
        <div class="input">
          <div class="input-prepend">
            <label class="add-on active">
              <input name="bbp_log_topic_edit" id="bbp_log_topic_edit" type="checkbox" value="1" <?php bbp_form_topic_log_edit(); ?> tabindex="<?php bbp_tab_index(); ?>" />
            </label>
            <input type="text" value="<?php bbp_form_topic_edit_reason(); ?>" tabindex="<?php bbp_tab_index(); ?>" size="40" name="bbp_topic_edit_reason" id="bbp_topic_edit_reason" />

            <span class="help-block"><?php atom()->te('Optionally, you can provide a reason for editing.', bbp_get_current_user_name()); ?></span>
          </div>
        </div>
      </div>
      <?php do_action('bbp_theme_after_topic_form_revisions'); ?>
      <?php endif; ?>

      <?php do_action('bbp_theme_before_topic_form_submit_wrapper'); ?>

      <div class="actions">
        <?php do_action('bbp_theme_before_topic_form_submit_button'); ?>
        <input type="submit" tabindex="<?php bbp_tab_index(); ?>" class="button ok" name="bbp_topic_submit" value="<?php atom()->te('Submit'); ?>" />
        <?php do_action('bbp_theme_after_topic_form_submit_button'); ?>
      </div>
      <?php do_action('bbp_theme_before_topic_form_submit_wrapper'); ?>
      <?php bbp_topic_form_fields(); ?>
    </fieldset>

    <?php do_action('bbp_theme_after_topic_form'); ?>

  </form>
</div>



<?php elseif(bbp_is_forum_closed()): ?>

  <div id="no-topic-<?php bbp_topic_id(); ?>" class="bbp-no-topic">
    <div class="bbp-template-notice">
      <p><?php atom()->te('The forum &#8216;%s&#8217; is closed to new topics and replies.', bbp_get_forum_title()); ?></p>
    </div>
  </div>

<?php else: ?>

  <div id="no-topic-<?php bbp_topic_id(); ?>" class="bbp-no-topic">
    <div class="bbp-template-notice">
      <p><?php is_user_logged_in() ? atom()->te('You cannot create new topics at this time.') : atom()->te('You must be logged in to create new topics.'); ?></p>
    </div>
  </div>

<?php endif; ?>
